pub struct IPCComm { /* private fields */ }Implementations
Sourceimpl IPCComm
Simple length-prefixed Borsh-encoded messages
impl IPCComm
Simple length-prefixed Borsh-encoded messages
Sourcepub fn new(stream: UnixStream) -> Self
pub fn new(stream: UnixStream) -> Self
Consumes a unix stream for length-prefixed Borsh-encoded communication.
Sourcepub async fn new_with_identifier<I: BorshDeserialize>(
stream: UnixStream,
) -> Result<(Self, I), Error>
pub async fn new_with_identifier<I: BorshDeserialize>( stream: UnixStream, ) -> Result<(Self, I), Error>
Consumes a unix stream for length-prefixed Borsh-encoded communication.
Waits until type I is received, will error if the initial message couldn’t be decoded.
Sourcepub async fn send_msg<S: BorshSerialize>(&mut self, msg: S) -> Result<(), Error>
pub async fn send_msg<S: BorshSerialize>(&mut self, msg: S) -> Result<(), Error>
Adds the provided message to a queue for sending over the underlying connection, but does not wait until the message is actually sent
Sourcepub fn blocking_send_msg<S: BorshSerialize>(
&mut self,
msg: S,
) -> Result<(), Error>
pub fn blocking_send_msg<S: BorshSerialize>( &mut self, msg: S, ) -> Result<(), Error>
Adds the provided message to a queue for sending over the underlying connection, but does not block until the message is actually sent
Sourcepub async fn recv_msg<R: BorshDeserialize>(
&mut self,
) -> Result<Option<R>, Error>
pub async fn recv_msg<R: BorshDeserialize>( &mut self, ) -> Result<Option<R>, Error>
Removes and parses a message received messages queue. If there are no pending messages, None is returned.
Sourcepub async fn until_recv_msg<R: BorshDeserialize>(
&mut self,
) -> Result<Option<R>, Error>
pub async fn until_recv_msg<R: BorshDeserialize>( &mut self, ) -> Result<Option<R>, Error>
Removes and parses a message received messages queue. If there are no pending messages, this function waits until there is one. If the underlying connection is closed before a message could be received, None is returned.
Sourcepub async fn wait_until_stopped(self)
pub async fn wait_until_stopped(self)
Waits until the read/write tasks are stopped